<?php

/**
 * @file
 * Code for Iubenda Integration administration.
 */

/**
 * Iubenda Integration Privacy Policy settings form.
 */
function iubenda_integration_privacy_policy_settings_form($form, &$form_state) {

  $form['settings'] = array(
    '#type' => 'vertical_tabs',
  );

  $form['settings']['iubenda'] = array(
    '#title' => t('Iubenda'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
  );

  $form['settings']['iubenda']['iubenda_integration_policy_code'] = array(
    '#title' => t('Iubenda Privacy Policy code'),
    '#type' => 'textfield',
    '#description' => t('Insert the privacy policy code generated by Iubenda for your website.'),
    '#default_value' => variable_get('iubenda_integration_policy_code', ''),
    '#required' => TRUE,
    '#size' => 10,
  );

  $form['settings']['iubenda']['iubenda_integration_style'] = array(
    '#title' => t('Style'),
    '#type' => 'radios',
    '#options' => array(
      'iubenda-nostyle' => t('No style'),
      'iubenda-white' => t('White'),
      'iubenda-black' => t('Black'),
    ),
    '#default_value' => variable_get('iubenda_integration_style', 'iubenda-nostyle'),
    '#required' => TRUE,
  );

  $form['settings']['iubenda']['iubenda_integration_legal_only'] = array(
    '#title' => t('Show legal only'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('iubenda_integration_legal_only', FALSE),
  );

  $form['settings']['iubenda']['iubenda_integration_show_brand'] = array(
    '#title' => t('Show brand'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('iubenda_integration_show_brand', FALSE),
  );

  $form['settings']['form'] = array(
    '#title' => t('Form'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['settings']['form']['iubenda_integration_form_element_type'] = array(
    '#title' => t('Form element type'),
    '#type' => 'select',
    '#options' => array(
      'checkbox' => t('Checkbox'),
      'radio' => t('Radio'),
    ),
    '#default_value' => variable_get('iubenda_integration_form_element_type', 'checkbox'),
  );

  $form['settings']['form']['iubenda_integration_forms'] = array(
    '#title' => t('Privacy Policy Forms'),
    '#description' => t('Insert here, one per line, a list of form ids for which Iubenda Privacy Policy have to be displayed.'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_forms', ''),
  );

  $form['settings']['form']['text'] = array(
    '#title' => t('Text'),
    '#type' => 'fieldset',
  );

  $form['settings']['form']['text']['iubenda_integration_pretext'] = array(
    '#title' => t('Pre-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to precede Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_pretext', ''),
  );

  $form['settings']['form']['text']['iubenda_integration_text'] = array(
    '#title' => t('Link Text'),
    '#description' => t('Insert text that will be displayed as link'),
    '#type' => 'textfield',
    '#default_value' => variable_get('iubenda_integration_text', t('Privacy Policy')),
    '#required' => TRUE,
  );

  $form['settings']['form']['text']['iubenda_integration_posttext'] = array(
    '#title' => t('Post-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to follow Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_posttext', ''),
  );

  $form['settings']['block'] = array(
    '#title' => t('Block'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['settings']['block']['iubenda_integration_block_pretext'] = array(
    '#title' => t('Pre-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to precede Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_block_pretext', ''),
  );

  $form['settings']['block']['iubenda_integration_block_text'] = array(
    '#title' => t('Link Text'),
    '#description' => t('Insert text that will be displayed as link'),
    '#type' => 'textfield',
    '#default_value' => variable_get('iubenda_integration_block_text', t('Privacy Policy')),
    '#required' => TRUE,
  );

  $form['settings']['block']['iubenda_integration_block_posttext'] = array(
    '#title' => t('Post-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to follow Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_block_posttext', ''),
  );

  return system_settings_form($form);
}

/**
 * Iubenda Integration Cookie Policy settings form.
 */
function iubenda_integration_cookie_policy_settings_form($form, &$form_state) {
  $form['#form_id'] = __FUNCTION__;
  $form['#prefix'] = '<div id="iubenda_integration_cookie_policy_wrapper">';
  $form['#suffix'] = '</div>';

  $default_enabled = variable_get('iubenda_integration_cookie_policy_enabled', FALSE);
  $enabled = isset($form_state['values']['iubenda_integration_cookie_policy_enabled']) ? $form_state['values']['iubenda_integration_cookie_policy_enabled'] : $default_enabled;

  $form['iubenda_integration_cookie_policy_enabled'] = array(
    '#title' => t('Enable EU Cookie Policy'),
    '#type' => 'checkbox',
    '#default_value' => $enabled,
    '#ajax' => array(
      'wrapper' => 'iubenda_integration_cookie_policy_wrapper',
      'callback' => 'iubenda_integration_cookie_policy_ajax_callback',
    ),
  );

  $settings = variable_get('iubenda_integration_cookie_policy', array());
  $form['iubenda_integration_cookie_policy'] = array(
    '#tree' => TRUE,
    '#access' => $enabled,
  );

  $form['iubenda_integration_cookie_policy']['siteId'] = array(
    '#title' => t('Site ID'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#size' => 10,
    '#default_value' => !empty($settings['siteId']) ? $settings['siteId'] : NULL,
    '#description' => t('Id of the site (note: this ID is used to share the preferences of various cookie policies in multiple languages that are however connected to the same site/app)'),
  );

  $form['iubenda_integration_cookie_policy']['cookiePolicyId'] = array(
    '#title' => t('Cookie Policy ID'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#size' => 10,
    '#default_value' => !empty($settings['cookiePolicyId']) ? $settings['cookiePolicyId'] : NULL,
    '#description' => t('Id of your cookie policy'),
  );

  $form['iubenda_integration_cookie_policy']['cookiePolicyUrl'] = array(
    '#title' => t('Cookie Policy URL'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['cookiePolicyUrl']) ? $settings['cookiePolicyUrl'] : NULL,
    '#description' => t('The URL of your cookie policy, available in your dashboard, or from any page that hosts the policy.'),
  );

  $form['iubenda_integration_cookie_policy']['cookiePolicyInOtherWindow'] = array(
    '#title' => t('Cookie Policy in other window'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['cookiePolicyInOtherWindow']) ? $settings['cookiePolicyInOtherWindow'] : FALSE,
    '#description' => t('Set to true if you want the cookie policy to open in another window and not in the lightbox/iubenda modal.'),
  );

  $form['iubenda_integration_cookie_policy']['enableRemoteConsent'] = array(
    '#title' => t('Enable remote consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['enableRemoteConsent']) ? $settings['enableRemoteConsent'] : FALSE,
    '#description' => t('Set to false to avoid the registration of consent "cross-site" on the domain iubenda.com.'),
  );

  $form['iubenda_integration_cookie_policy']['consentOnScroll'] = array(
    '#title' => t('Consent on scroll'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['consentOnScroll']) ? $settings['consentOnScroll'] : TRUE,
    '#description' => t('Set to false to avoid the registration of consent at the scrolling of the page.'),
  );

  $form['iubenda_integration_cookie_policy']['reloadOnConsent'] = array(
    '#title' => t('Reload on consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['reloadOnConsent']) ? $settings['reloadOnConsent'] : FALSE,
    '#description' => t('Set to true if you want to reload the page when the user gives his consent.'),
  );

  $form['iubenda_integration_cookie_policy']['localConsentDomain'] = array(
    '#title' => t('Load consent domain'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['reloadOnConsent']) ? $settings['reloadOnConsent'] : NULL,
    '#description' => t('The domain on which you want the consent given by the user saved. If this parameter isn’t given, the consent gets saved by default in a cookie for the domain on a second level of the current page (for example: visiting www.example.com, the consent gets saved in a cookie on the on the domain .example.com). In the case in which the default behavior isn’t suitable, for example if the site were www.paesaggiurbani.italia.it and the consent needs to be saved for paesaggiurbani.italia.it, you need to fill that parameter with ‘paesaggiurbani.italia.it’.'),
  );

  $form['iubenda_integration_cookie_policy']['localConsentPath'] = array(
    '#title' => t('Load consent path'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['localConsentPath']) ? $settings['localConsentPath'] : '/',
    '#description' => t('The path at which you’ll want, on the local domain, the consent by the user saved. By default, the consent given by the user gets saved on the local domain in a cookie on the path ‘/’. In this way, the cookie is available at whichever page of the domain that a user accesses. If on the other hand one would like to not make the preference cookie set for www.example.com/user1 available on www.example.com/user2, and vice versa, you’ll need to set this parameter to the calue ‘/user1’ in the first case and the value to ‘/user2’ in the second.'),
  );

  $form['iubenda_integration_cookie_policy']['banner'] = array(
    '#title' => t('Banner'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['iubenda_integration_cookie_policy']['banner']['slideDown'] = array(
    '#title' => t('Slide down'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['slideDown']) ? $settings['banner']['slideDown'] : TRUE,
    '#description' => t('Set to false to remove the initial banner animation'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['zIndex'] = array(
    '#title' => t('zIndex'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['zIndex']) ? $settings['banner']['zIndex'] : NULL,
    '#description' => t('zIndex of the div of the banner of the cookie policy (default value: 99999998).'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['content'] = array(
    '#title' => t('Content'),
    '#type' => 'textarea',
    '#default_value' => !empty($settings['banner']['content']) ? $settings['banner']['content'] : NULL,
    '#description' => t('content (text) with the notice of the cookie policy (current default:"<pre>
Notice

This website or its third party tools use cookies, which are necessary to its functioning and required to achieve the purposes illustrated in the %{cookie_policy_link}. If you want to know more or withdraw your consent to all or some of the cookies, please refer to the cookie policy.
By closing this banner, scrolling this page, clicking a link or continuing to browse otherwise, you agree to the use of cookies.

</pre>", where %{cookie_policy_link} is the placeholder for the cookie policy link).'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['cookiePolicyLinkCaption'] = array(
    '#title' => t('Cookie Policy link caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['cookiePolicyLinkCaption']) ? $settings['banner']['cookiePolicyLinkCaption'] : NULL,
    '#description' => t('Anchor text of the link to the cookie policy (default value: "cookie policy").'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['backgroundColor'] = array(
    '#title' => t('Background color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['backgroundColor']) ? $settings['banner']['backgroundColor'] : NULL,
    '#description' => t('(default "#000") background color of the banner.'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['textColor'] = array(
    '#title' => t('Text color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['textColor']) ? $settings['banner']['textColor'] : NULL,
    '#description' => t('(default "#fff") text color of the banner.'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['fontSize'] = array(
    '#title' => t('Font size'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['fontSize']) ? $settings['banner']['fontSize'] : NULL,
    '#description' => t('(default "14px") text size of the banner.'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['innerHtmlCloseBtn'] = array(
    '#title' => t('Close button - inner HTML'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['innerHtmlCloseBtn']) ? $settings['banner']['innerHtmlCloseBtn'] : NULL,
    '#description' => t('(default "x") closing button text for the banner.'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['applyStyles'] = array(
    '#title' => t('Apply styles'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['applyStyles']) ? $settings['banner']['applyStyles'] : TRUE,
    '#description' => t('(default true) if set to false, then banner doesn’t have any style applied/CSS.'),
  );

  $form['iubenda_integration_cookie_policy']['banner']['html'] = array(
    '#title' => t('HTML'),
    '#type' => 'textarea',
    '#default_value' => !empty($settings['banner']['html']) ? $settings['banner']['html'] : NULL,
    '#description' => t('HTML of the banner to substitute the default version. NOTE: the following elements are necessary for the correct functioning of the banner:
<ul>
<li>div.iubenda-cs-content [main content]</li>
<li>a.iubenda-cs-cookie-policy-lnk [link with href set to the cookie policy, i.e. https://www.iubenda.com/privacy-policy/417383/cookie-policy?an=no&s_ck=false]</li>
<li>a.iubenda-cs-close-btn [close button for the banner]</li>
</ul>'),
  );

  $form['iubenda_integration_cookie_policy']['footer'] = array(
    '#title' => t('Footer'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['iubenda_integration_cookie_policy']['footer']['message'] = array(
    '#title' => t('Message'),
    '#type' => 'textarea',
    '#default_value' => !empty($settings['footer']['message']) ? $settings['footer']['message'] : NULL,
    '#description' => t('Text message visualized below the details of the cookie policy (default value: "By continuing to browse or by closing this window, you accept the use of cookies.").'),
  );

  $form['iubenda_integration_cookie_policy']['footer']['btnCaption'] = array(
    '#title' => t('Button caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['footer']['btnCaption']) ? $settings['footer']['btnCaption'] : NULL,
    '#description' => t('Text message inserted in the button to confirm and consent to the cookie policy (default value: "Continue to browse").'),
  );

  $form['iubenda_integration_cookie_policy']['callback'] = array(
    '#title' => t('Callback'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['iubenda_integration_cookie_policy']['callback']['onBannerShown'] = array(
    '#title' => t('On banner shown'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['callback']['onBannerShown']) ? $settings['callback']['onBannerShown'] : NULL,
    '#description' => t('function – called when the banner is shown.'),
  );

  $form['iubenda_integration_cookie_policy']['callback']['onConsentGiven'] = array(
    '#title' => t('On consent given'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['callback']['onConsentGiven']) ? $settings['callback']['onConsentGiven'] : NULL,
    '#description' => t('function – called at the moment when the user consents to the cookie policy and therefore to the use of cookies.'),
  );

  $form['iubenda_integration_cookie_policy']['preferenceCookie'] = array(
    '#title' => t('Preference Cookie'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['iubenda_integration_cookie_policy']['preferenceCookie']['expireAfter'] = array(
    '#title' => t('Expire after'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['preferenceCookie']['expireAfter']) ? $settings['preferenceCookie']['expireAfter'] : NULL,
    '#description' => t('(default 365) number of days that the consent will remain valid for this website.'),
  );

  $form['iubenda_integration_cookie_policy']['developers'] = array(
    '#title' => t('Parameters for developers'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['iubenda_integration_cookie_policy']['developers']['logLevel'] = array(
    '#title' => t('Log level'),
    '#type' => 'select',
    '#options' => array(
      '' => t('- Select -'),
      'debug' => t('Debug'),
      'info' => t('info'),
      'warn' => t('warn'),
      'error' => t('error'),
      'fatal' => t('fatal'),
    ),
    '#default_value' => !empty($settings['developers']['logLevel']) ? $settings['developers']['logLevel'] : NULL,
  );

  $form['iubenda_integration_cookie_policy']['developers']['skipSaveConsent'] = array(
    '#title' => t('Skip save consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['developers']['skipSaveConsent']) ? $settings['developers']['skipSaveConsent'] : FALSE,
    '#description' => t('true (default value) if the consent doesn’t need to be saved in the preference cookies.'),
  );

  $form['iubenda_integration_cookie_policy']['developers']['logViaAlert'] = array(
    '#title' => t('Log via alert'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['developers']['logViaAlert']) ? $settings['developers']['logViaAlert'] : FALSE,
    '#description' => t('default value: false. True if the logging needs to be shown via alert.'),
  );

  $form['iubenda_integration_cookie_policy']['consentOnButton'] = array(
    '#title' => t('Consent on button'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['consentOnButton']) ? $settings['consentOnButton'] : FALSE,
    '#description' => t('Allows to activate the cookie policy also via clicking on the buttons button present in the page, other than the links.'),
  );

  return system_settings_form($form);
}

/**
 * Ajax callback.
 *
 * @see iubenda_integration_cookie_policy_settings_form()
 */
function iubenda_integration_cookie_policy_ajax_callback($form, &$form_state) {
  return $form;
}
